% Cloud top height for ARM case

clear

% Build a bespoke colormap for cloud top
map( 1: 32,1:3) = ones(32,1)*[0.75,1.0,0.5];  % Green for ARM
% map( 1: 32,1:3) = ones(32,1)*[0.3,0.3,1.0];  % Blue for BOMEX and DYCOMS
map(33:256,1:3) = (0.7 + 0.3*([1:224]/224))'*[1,1,1];

% For labelling plot panels
paneltext = 'abc';

% Loop over files
plt = 0;
for time = [21600,28800,35520]
    plt = plt + 1;

    % Build name of file to read
    yfile = ['run000002_xy_diags_',num2str(time,'%010i'),'.dat']

    % Retrieve the required field
    [ctop,model_time,x,y,levels] = retrieve_field(yfile,'ctop');
    nx = numel(x);
    ny = numel(y);
    % Convert to km
    x = 0.001*x;
    y = 0.001*y;

    % Determine plot domain to draw a border
    dx = x(2) - x(1);
    dy = y(2) - y(1);
    xmin = 0.0; xmax = nx*dx;
    ymin = 0.0; ymax = ny*dy;

    % And plot

    figure(1)
    subplot(1,3,plt)
    hold on
    clev = [-1,800:100:4000];   % ARM
    % clev = [-1,500:100:2000];   % BOMEX
    % clev = [-1,350:50:900];     % DYCOMS
    contourf(x,y,ctop',clev,'k')
    colormap(map)
    clim([0,2500])    % ARM
    % clim([0,1700])    % BOMEX
    % clim([0,900])     % DYCOMS
    % Add thicker border for contrast in DYCOMS case
    plot([xmin,xmax,xmax,xmin,xmin],[ymin,ymin,ymax,ymax,ymin],'k','linewidth',3)
    hold off
    title(['(',paneltext(plt),') Cloud top,   t = ',num2str(model_time)])
    xlabel('x (km)')
    ylabel('y (km)')
    axis square
    set(gca,'fontsize',18)

    pause(0.25)
    %pause

end


