% Plot convergence diagnostics from PTerodaCTILES

clear

% File to read
yfile = 'solver_convergence.dat';

% Read the data
gdiags = load(yfile);

% Determine number of time and iteration points
[ntimeiter,eleven] = size(gdiags);
ntime = max(gdiags(:,1));
niter = max(gdiags(:,2));

% Unpack data
step      = gdiags(:, 1);
iter      = gdiags(:, 2);
res_rho   = gdiags(:, 3);
res_qt    = gdiags(:, 4);
res_etat  = gdiags(:, 5);
res_u     = gdiags(:, 6);
res_v     = gdiags(:, 7);
res_w_dp  = gdiags(:, 8);
res_buoy  = gdiags(:, 9);
rhs_helm  = gdiags(:,10);
p_inc     = gdiags(:,11);

% reshape into niter * nstep arrays
step      = reshape(step    ,niter,ntime);
iter      = reshape(iter    ,niter,ntime);
res_rho   = reshape(res_rho ,niter,ntime);
res_qt    = reshape(res_qt  ,niter,ntime);
res_etat  = reshape(res_etat,niter,ntime);
res_u     = reshape(res_u   ,niter,ntime);
res_v     = reshape(res_v   ,niter,ntime);
res_w_dp  = reshape(res_w_dp,niter,ntime);
res_buoy  = reshape(res_buoy,niter,ntime);
rhs_helm  = reshape(rhs_helm,niter,ntime);
p_inc     = reshape(p_inc   ,niter,ntime);

% And plot

% Line styles for different iterations
ls = ["r","b","g","k","r--","b--","g--","k--","r:","b:","g:","k:"];

figure(1)

lw = 1.5;
fs = 14;

% Residual in the total water equation
subplot(1,3,1)
semilogy(res_qt(:,1),'b-o','linewidth',lw)
ylim([1e-16,1])
yticks([1e-16,1e-12,1e-8,1e-4,1])
xlabel('Iteration')
ylabel('Residual')
title('(a) q equation')
set(gca,'fontsize',fs)

% % Residual in the total entropy equation
% subplot(1,3,2)
% semilogy(res_etat(:,1),'b-o','linewidth',lw)
% yticks([1e-12,1e-8,1e-4,1])
% xlabel('Iter')
% ylabel('res \eta^t')
% set(gca,'fontsize',fs)

% Residual in the u equation
subplot(1,3,2)
semilogy(res_u(:,1),'b-o','linewidth',lw)
ylim([1e-8,10])
yticks([1e-8,1e-6,1e-4,1e-2,1])
xlabel('Iteration')
title('(b) u equation')
set(gca,'fontsize',fs)


% p increment
subplot(1,3,3)
semilogy(p_inc(:,1),'b-o','linewidth',lw)
ylim([1e-8,1e2])
yticks([1e-8,1e-6,1e-4,1e-2,1])
xlabel('Iteration')
title('(c) p increment')
set(gca,'fontsize',fs)

% % Residual in the rho equation
% subplot(5,2,1)
% for i = 1:niter
%   semilogy(step(i,:),res_rho(i,:),ls(i))
%   hold on
% end
% hold off
% xlabel('Step')
% ylabel('res rho')
% 
% % Residual in the total water equation
% subplot(5,2,3)
% for i = 1:niter
%   semilogy(step(i,:),res_qt(i,:),ls(i))
%   hold on
% end
% hold off
% xlabel('Step')
% ylabel('res qt')
% 
% % Residual in the total entropy equation
% subplot(5,2,5)
% for i = 1:niter
%   semilogy(step(i,:),res_etat(i,:),ls(i))
%   hold on
% end
% hold off
% xlabel('Step')
% ylabel('res etat')
% 
% % Residual in the u equation
% subplot(5,2,7)
% for i = 1:niter
%   semilogy(step(i,:),res_u(i,:),ls(i))
%   hold on
% end
% hold off
% xlabel('Step')
% ylabel('res u')
% 
% % Residual in the v equation
% subplot(5,2,9)
% for i = 1:niter
%   semilogy(step(i,:),res_v(i,:),ls(i))
%   hold on
% end
% hold off
% xlabel('Step')
% ylabel('res v')
% 
% % Residual in the w-p equation
% subplot(5,2,2)
% for i = 1:niter
%   semilogy(step(i,:),res_w_dp(i,:),ls(i))
%   hold on
% end
% hold off
% xlabel('Step')
% ylabel('res w dp')
% 
% % Residual in the buoyancy equation
% subplot(5,2,4)
% for i = 1:niter
%   semilogy(step(i,:),res_buoy(i,:),ls(i))
%   hold on
% end
% hold off
% xlabel('Step')
% ylabel('res buoy')
% 
% % RHS of the Helmholtz equation
% subplot(5,2,6)
% for i = 1:niter
%   semilogy(step(i,:),rhs_helm(i,:),ls(i))
%   hold on
% end
% hold off
% xlabel('Step')
% ylabel('rhs helm')
% 
% % p increment
% subplot(5,2,8)
% for i = 1:niter
%   semilogy(step(i,:),p_inc(i,:),ls(i))
%   hold on
% end
% hold off
% xlabel('Step')
% ylabel('p inc')

