% Plot global diagnostics from PTerodaCTILES
% All diagnostics are per unit horizontal area 

clear

% For clarity, option to plot every skip'th data point
skip = 10;

% File to read
yfile = 'run000002globaldiags.dat';

% Read the data
gdiags = load(yfile);

% Determine number of time points
[ntime,twentynine] = size(gdiags);

% Unpack data, subsample as we do so
trange = [1:skip:ntime];
time    = gdiags(trange, 1);
mass    = gdiags(trange, 2);
umom    = gdiags(trange, 3);
vmom    = gdiags(trange, 4);
pe      = gdiags(trange, 5);
ke      = gdiags(trange, 6);
tke     = gdiags(trange, 7);
massw   = gdiags(trange, 8);
water   = gdiags(trange, 9);
vapour  = gdiags(trange,10);
liquid  = gdiags(trange,11);
frozen  = gdiags(trange,12);
entropy = gdiags(trange,13);
ie      = gdiags(trange,14);
sfc_src_mass    = gdiags(trange,15);
sfc_src_water   = gdiags(trange,16);
sfc_src_entropy = gdiags(trange,17);
sfc_src_energy  = gdiags(trange,18);
sfc_src_umom    = gdiags(trange,19);
sfc_src_vmom    = gdiags(trange,20);
lrg_scl_src_mass    = gdiags(trange,21);
lrg_scl_src_water   = gdiags(trange,22);
lrg_scl_src_entropy = gdiags(trange,23);
lrg_scl_src_energy  = gdiags(trange,24);
lrg_scl_src_umom    = gdiags(trange,25);
lrg_scl_src_vmom    = gdiags(trange,26);
accum_pe_dissn  = gdiags(trange,27);
accum_ke_dissn  = gdiags(trange,28);
accum_ie_dissn  = gdiags(trange,29);

drymass = mass - water;
e = ke + pe + ie;

% Convert to hours
time = time/3600;

% And plot
figure(1)
% Fontsize
fs = 15;

% Change in total mass;
% Change in dry mass;
% Accumulated mass sources.
subplot(3,2,1)
plot(time,mass-mass(1),'b',...
     time,sfc_src_mass+lrg_scl_src_mass,'bo',...
     time,drymass-drymass(1),'k',...
     'linewidth',1.5)
title('(a) Mass, dry mass, mass source')
ylim([-1,6])
xticks([0:2:14])
legend('Chng tot mass','Tot mass src','Chng dry mass','location','northwest')
set(gca,'fontsize',fs)

% Liquid mass;
% Frozen mass;
% Change in total water mass;
% Accumulated total water source;
subplot(3,2,2)
plot(time,100*liquid,'r',time,100*frozen,'b',...
     time,water-water(1),'k',time,sfc_src_water+lrg_scl_src_water,'ko','linewidth',1.5)
title('(b) Water, water source')
xticks([0:2:14])
ylim([-1,6])
legend('100 x liquid','100 x frozen','Chng tot water','Tot water src','location','northwest')
set(gca,'fontsize',fs)

% Change in eastward momentum;
% Change in northward momentum;
% Accumulated total eastard momentum source;
% Accumulated total northward momentum source.
subplot(3,2,3)
plot(time,umom-umom(1),'b',time,vmom-vmom(1),'r',...
     time,sfc_src_umom+lrg_scl_src_umom,'bo',...
     time,sfc_src_vmom+lrg_scl_src_vmom,'ro','linewidth',1.5)
title('(c) umom, vmom, sources')
ylim([-1e4,2.5e4])
xticks([0:2:14])
legend('Chng u mom','Chng v mom','Src u mom','Src v mom','location','northwest')
set(gca,'fontsize',fs)

% Change in entropy;
% Accumulated total entropy source;
subplot(3,2,4)
plot(time,entropy-entropy(1),'k',...
     time,sfc_src_entropy+lrg_scl_src_entropy,'ko','linewidth',1.5)
title('(d) Entropy and source')
xticks([0:2:14])
legend('Chng entropy','Src entropy','location','northwest')
set(gca,'fontsize',fs)

% Change in total energy;
% Accumulated total surface and large-scale energy sources;
subplot(3,2,5)
plot(time,e - e(1),'k',time,sfc_src_energy+lrg_scl_src_energy,'ko','linewidth',1.5)
title('(e) Energy and source')
xticks([0:2:14])
xlabel('Time (h)')
legend('Chng energy','Src energy','location','northwest')
set(gca,'fontsize',fs)

% Energy change due to numerical dissipation and mixing
subplot(3,2,6)
plot(time,e - e(1) - (sfc_src_energy+lrg_scl_src_energy),'k','linewidth',1.5)
title('(f) Numerical energy change')
xticks([0:2:14])
xlabel('Time (h)')
set(gca,'fontsize',fs)

