% Build and plot time averages from column data
% for ARM

clear

% Height range to plot (km)
zrange = [0,3];


% First some averages over 2.5 - 3.5 hours
% Initialize counter
nt = 0;
first = 1;
% Loop over files
for time = [9000:120:12600]

    % Build name of file to read
    yfile = ['run000002columndiags_',num2str(time,'%010i'),'.dat']

    % Read in the data
    [model_time,nz,zp,zw,rho,p,u,v,w_at_p,ke,uvar,vvar,wvar,           ...
     tke,uflx,vflx,rho_at_w,w,water,vapour,liquid,frozen,etat,qvar,    ...
     qflx,etaflx,temperature,p_at_w,rh,n2,alpha,cld_frac,          ...
     rad_trcr,rad_trcr_var,updraft_indi,entrainment,detrainment,   ...
     pe_dissipation,ke_dissipation,ie_dissipation] = read_a_column(yfile);
 
    if first

        nzp = nz + 1;

        % Intialize averages
        ave_p        = zeros(1,nz);
        ave_u        = zeros(1,nz);
        ave_v        = zeros(1,nz);
        ave_w_at_p   = zeros(1,nz);
        ave_ke       = zeros(1,nz);
        ave_uvar     = zeros(1,nz);
        ave_vvar     = zeros(1,nz);
        ave_wvar     = zeros(1,nz);
        ave_tke      = zeros(1,nz);
        ave_uflx     = zeros(1,nz);
        ave_vflx     = zeros(1,nz);
        ave_w        = zeros(1,nzp);
        ave_water    = zeros(1,nzp);
        ave_vapour   = zeros(1,nzp);
        ave_liquid   = zeros(1,nzp);
        ave_frozen   = zeros(1,nzp);
        ave_etat     = zeros(1,nzp);
        ave_qvar     = zeros(1,nzp);
        ave_qflx     = zeros(1,nzp);
        ave_etaflx   = zeros(1,nzp);
        ave_temperature = zeros(1,nzp);
        ave_p_at_w   = zeros(1,nzp);
        ave_rh       = zeros(1,nzp);
        ave_n2       = zeros(1,nzp);
        ave_alpha    = zeros(1,nzp);
        ave_cld_frac = zeros(1,nzp);
        ave_rad_trcr = zeros(1,nz);
        ave_rad_trcr_var = zeros(1,nz);
        ave_up_indi  = zeros(1,nzp);
        ave_entrain  = zeros(1,nzp);
        ave_detrain  = zeros(1,nzp);
        ave_pe_dissn = zeros(1,nz);
        ave_ke_dissn = zeros(1,nz);
        ave_ie_dissn = zeros(1,nzp);
       

        first = 0;

    end

    nt = nt + 1;
    % Accumulate totals
    ave_p        = ave_p        + p;
    ave_u        = ave_u        + u;
    ave_v        = ave_v        + v;
    ave_w_at_p   = ave_w_at_p   + w_at_p;
    ave_ke       = ave_ke       + ke;
    ave_uvar     = ave_uvar     + uvar;
    ave_vvar     = ave_vvar     + vvar;
    ave_wvar     = ave_wvar     + wvar;
    ave_tke      = ave_tke      + tke;
    ave_uflx     = ave_uflx     + uflx;
    ave_vflx     = ave_vflx     + vflx;
    ave_w        = ave_w        + w;
    ave_water    = ave_water    + water;
    ave_vapour   = ave_vapour   + vapour;
    ave_liquid   = ave_liquid   + liquid;
    ave_frozen   = ave_frozen   + frozen;
    ave_etat     = ave_etat     + etat;
    ave_qvar     = ave_qvar     + qvar;
    ave_qflx     = ave_qflx     + qflx;
    ave_etaflx   = ave_etaflx   + etaflx;
    ave_temperature = ave_temperature + temperature;
    ave_p_at_w   = ave_p_at_w   + p_at_w;
    ave_rh       = ave_rh       + rh;
    ave_n2       = ave_n2       + n2;
    ave_alpha    = ave_alpha    + alpha;
    ave_cld_frac = ave_cld_frac + cld_frac;
    ave_rad_trcr = ave_rad_trcr + rad_trcr;
    ave_rad_trcr_var = ave_rad_trcr_var + rad_trcr_var;
    ave_up_indi  = ave_up_indi  + updraft_indi;
    ave_entrain  = ave_entrain  + entrainment;
    ave_detrain  = ave_detrain  + detrainment;
    ave_pe_dissn = ave_pe_dissn + pe_dissipation;
    ave_ke_dissn = ave_ke_dissn + ke_dissipation;
    ave_ie_dissn = ave_ie_dissn + ie_dissipation;
 
end

% Convert sums to means
ave_p        = ave_p        / nt;
ave_u        = ave_u        / nt;
ave_v        = ave_v        / nt;
ave_w_at_p   = ave_w_at_p   / nt;
ave_ke       = ave_ke       / nt;
ave_uvar     = ave_uvar     / nt;
ave_vvar     = ave_vvar     / nt;
ave_wvar     = ave_wvar     / nt;
ave_tke      = ave_tke      / nt;
ave_uflx     = ave_uflx     / nt;
ave_vflx     = ave_vflx     / nt;
ave_w        = ave_w        / nt;
ave_water    = ave_water    / nt;
ave_vapour   = ave_vapour   / nt;
ave_liquid   = ave_liquid   / nt;
ave_frozen   = ave_frozen   / nt;
ave_etat     = ave_etat     / nt;
ave_qvar     = ave_qvar     / nt;
ave_qflx     = ave_qflx     / nt;
ave_etaflx   = ave_etaflx   / nt;
ave_temperature = ave_temperature / nt;
ave_p_at_w   = ave_p_at_w   / nt;
ave_rh       = ave_rh       / nt;
ave_n2       = ave_n2       / nt;
ave_alpha    = ave_alpha    / nt;
ave_cld_frac = ave_cld_frac / nt;
ave_rad_trcr = ave_rad_trcr / nt;
ave_rad_trcr_var = ave_rad_trcr_var / nt;
ave_up_indi  = ave_up_indi  / nt;
ave_entrain  = ave_entrain  / nt;
ave_detrain  = ave_detrain  / nt;
ave_pe_dissn = ave_pe_dissn / nt;
ave_ke_dissn = ave_ke_dissn / nt;
ave_ie_dissn = ave_ie_dissn / nt;

% And plot

figure(1)
clf

subplot(1,2,1)
plot(ave_wvar,zp,'k--','linewidth',1.5)
xlabel('(a) <w''w''> (m^2s^{-2})')
ylabel('height (km)')
ylim(zrange)
% legend('3h')
set(gca,'fontsize',12)
hold on

subplot(1,2,2)
plot(ave_uvar,zp,'k--','linewidth',1.5)
xlabel('(b) <u''u''> (m^2s^{-2})')
ylim(zrange)
% legend('3h')
set(gca,'fontsize',12)
hold on


% Now some averages over 8.5 - 9.5 hours
% Initialize counter
nt = 0;
first = 1;
% Loop over files
for time = [30600:120:34200]

    % Build name of file to read
    yfile = ['run000002columndiags_',num2str(time,'%010i'),'.dat']

    % Read in the data
    [model_time,nz,zp,zw,rho,p,u,v,w_at_p,ke,uvar,vvar,wvar,           ...
     tke,uflx,vflx,rho_at_w,w,water,vapour,liquid,frozen,etat,qvar,    ...
     qflx,etaflx,temperature,p_at_w,rh,n2,alpha,cld_frac,          ...
     rad_trcr,rad_trcr_var,updraft_indi,entrainment,detrainment,   ...
     pe_dissipation,ke_dissipation,ie_dissipation] = read_a_column(yfile);
 
    if first

        nzp = nz + 1;

        % Intialize averages
        ave_p        = zeros(1,nz);
        ave_u        = zeros(1,nz);
        ave_v        = zeros(1,nz);
        ave_w_at_p   = zeros(1,nz);
        ave_ke       = zeros(1,nz);
        ave_uvar     = zeros(1,nz);
        ave_vvar     = zeros(1,nz);
        ave_wvar     = zeros(1,nz);
        ave_tke      = zeros(1,nz);
        ave_uflx     = zeros(1,nz);
        ave_vflx     = zeros(1,nz);
        ave_w        = zeros(1,nzp);
        ave_water    = zeros(1,nzp);
        ave_vapour   = zeros(1,nzp);
        ave_liquid   = zeros(1,nzp);
        ave_frozen   = zeros(1,nzp);
        ave_etat     = zeros(1,nzp);
        ave_qvar     = zeros(1,nzp);
        ave_qflx     = zeros(1,nzp);
        ave_etaflx   = zeros(1,nzp);
        ave_temperature = zeros(1,nzp);
        ave_p_at_w   = zeros(1,nzp);
        ave_rh       = zeros(1,nzp);
        ave_n2       = zeros(1,nzp);
        ave_alpha    = zeros(1,nzp);
        ave_cld_frac = zeros(1,nzp);
        ave_rad_trcr = zeros(1,nz);
        ave_rad_trcr_var = zeros(1,nz);
        ave_up_indi  = zeros(1,nzp);
        ave_entrain  = zeros(1,nzp);
        ave_detrain  = zeros(1,nzp);
        ave_pe_dissn = zeros(1,nz);
        ave_ke_dissn = zeros(1,nz);
        ave_ie_dissn = zeros(1,nzp);
       

        first = 0;

    end

    nt = nt + 1;
    % Accumulate totals
    ave_p        = ave_p        + p;
    ave_u        = ave_u        + u;
    ave_v        = ave_v        + v;
    ave_w_at_p   = ave_w_at_p   + w_at_p;
    ave_ke       = ave_ke       + ke;
    ave_uvar     = ave_uvar     + uvar;
    ave_vvar     = ave_vvar     + vvar;
    ave_wvar     = ave_wvar     + wvar;
    ave_tke      = ave_tke      + tke;
    ave_uflx     = ave_uflx     + uflx;
    ave_vflx     = ave_vflx     + vflx;
    ave_w        = ave_w        + w;
    ave_water    = ave_water    + water;
    ave_vapour   = ave_vapour   + vapour;
    ave_liquid   = ave_liquid   + liquid;
    ave_frozen   = ave_frozen   + frozen;
    ave_etat     = ave_etat     + etat;
    ave_qvar     = ave_qvar     + qvar;
    ave_qflx     = ave_qflx     + qflx;
    ave_etaflx   = ave_etaflx   + etaflx;
    ave_temperature = ave_temperature + temperature;
    ave_p_at_w   = ave_p_at_w   + p_at_w;
    ave_rh       = ave_rh       + rh;
    ave_n2       = ave_n2       + n2;
    ave_alpha    = ave_alpha    + alpha;
    ave_cld_frac = ave_cld_frac + cld_frac;
    ave_rad_trcr = ave_rad_trcr + rad_trcr;
    ave_rad_trcr_var = ave_rad_trcr_var + rad_trcr_var;
    ave_up_indi  = ave_up_indi  + updraft_indi;
    ave_entrain  = ave_entrain  + entrainment;
    ave_detrain  = ave_detrain  + detrainment;
    ave_pe_dissn = ave_pe_dissn + pe_dissipation;
    ave_ke_dissn = ave_ke_dissn + ke_dissipation;
    ave_ie_dissn = ave_ie_dissn + ie_dissipation;
 
end

% Convert sums to means
ave_p        = ave_p        / nt;
ave_u        = ave_u        / nt;
ave_v        = ave_v        / nt;
ave_w_at_p   = ave_w_at_p   / nt;
ave_ke       = ave_ke       / nt;
ave_uvar     = ave_uvar     / nt;
ave_vvar     = ave_vvar     / nt;
ave_wvar     = ave_wvar     / nt;
ave_tke      = ave_tke      / nt;
ave_uflx     = ave_uflx     / nt;
ave_vflx     = ave_vflx     / nt;
ave_w        = ave_w        / nt;
ave_water    = ave_water    / nt;
ave_vapour   = ave_vapour   / nt;
ave_liquid   = ave_liquid   / nt;
ave_frozen   = ave_frozen   / nt;
ave_etat     = ave_etat     / nt;
ave_qvar     = ave_qvar     / nt;
ave_qflx     = ave_qflx     / nt;
ave_etaflx   = ave_etaflx   / nt;
ave_temperature = ave_temperature / nt;
ave_p_at_w   = ave_p_at_w   / nt;
ave_rh       = ave_rh       / nt;
ave_n2       = ave_n2       / nt;
ave_alpha    = ave_alpha    / nt;
ave_cld_frac = ave_cld_frac / nt;
ave_rad_trcr = ave_rad_trcr / nt;
ave_rad_trcr_var = ave_rad_trcr_var / nt;
ave_up_indi  = ave_up_indi  / nt;
ave_entrain  = ave_entrain  / nt;
ave_detrain  = ave_detrain  / nt;
ave_pe_dissn = ave_pe_dissn / nt;
ave_ke_dissn = ave_ke_dissn / nt;
ave_ie_dissn = ave_ie_dissn / nt;

% And plot

subplot(1,2,1)
plot(ave_wvar,zp,'k-','linewidth',1.5)
xlabel('(a) <w''w''> (m^2s^{-2})')
ylabel('height (km)')
ylim(zrange)
legend('3h','9h')
set(gca,'fontsize',12)
hold off

subplot(1,2,2)
plot(ave_uvar,zp,'k-','linewidth',1.5)
xlabel('(b) <u''u''> (m^2s^{-2})')
ylim(zrange)
legend('3h','9h')
set(gca,'fontsize',12)
hold off



