% Build and plot time series from column data

clear


% Build a bespoke colormap for tke
map(1:256,1) = 1 - 0.7*[1:256]/256;
map(1:256,2) = 1 - 0.4*[1:256]/256;
map(1:256,3) = 1 - [1:256]/256;

% Initialize counter
nt = 0;

% Loop over files
for time = [0:120:14400]

    % Build name of file to read
    yfile = ['run000003columndiags_',num2str(time,'%010i'),'.dat']

    % Read in the data
    [model_time,nz,zp,zw,rho,p,u,v,w_at_p,ke,uvar,vvar,wvar, ...
     tke,uflx,vflx,rho_at_w,w,water,vapour,liquid,frozen,etat,qvar,         ...
     qflx,etaflx,temperature,p_at_w,rh,n2,alpha,cld_frac,          ...
     rad_trcr,rad_trcr_var,updraft_indi,entrainment,detrainment,   ...
     pe_dissipation,ke_dissipation,ie_dissipation] = read_a_column(yfile);
 
    nt = nt + 1;
    cf(:,nt) = cld_frac;
    turbke(:,nt) = tke;
    press(:,nt) = p_at_w;
    water_flux(:,nt) = qflx;
    mtime(nt) = model_time;
 
end

subplot(1,1,1)
hold off

% Colour plot of tke
pcolor(mtime/3600,zp,turbke)
colormap(map)
shading interp
hold on

% with contours of cloud fraction
contour(mtime/3600,zw,cf,...
        [0.1:0.1:0.9,0.99],'k','linewidth',1.5)


set(gca,'fontsize',16)
xlabel('Time (h)')
ylabel('z (km)')
title('TKE and cloud frac for DYCOMS')

% Border, otherwise it's too faint
tt = [0,mtime(end),mtime(end),0,0]/3600;
zz = [zp(1),zp(1),zp(end),zp(end),zp(1)];
plot(tt,zz,'k','linewidth',2)
