% Build and plot time series from column data
% and x-y data for the DYCOMS case

clear

% Initialize counter
nt = 0;

% Loop over files
for time = [0:120:14400]

    % Build name of column data file to read
    yfile = ['run000003columndiags_',num2str(time,'%010i'),'.dat']

    % Read in the data
    [model_time,nz,zp,zw,rho,p,u,v,w_at_p,ke,uvar,vvar,wvar, ...
     tke,uflx,vflx,rho_at_w,w,water,vapour,liquid,frozen,etat,qvar,         ...
     qflx,etaflx,temperature,p_at_w,rh,n2,alpha,cld_frac,          ...
     rad_trcr,rad_trcr_var,updraft_indi,entrainment,detrainment,   ...
     pe_dissipation,ke_dissipation,ie_dissipation] = read_a_column(yfile);
    
    nt = nt + 1;
    mtime(nt) = model_time;

    % Extract layer thicknesses;
    % convert km back to m
    dzp = 1000*(zw(2:end) - zw(1:end-1));
    dzw = 1000*([zp(1)-zw(1),zp(2:end) - zp(1:end-1),zw(end)-zp(end)]);

    % Compute column integrals
    coltke(nt) = sum(rho.*tke.*dzp);
    collwp(nt) = sum(rho_at_w.*liquid.*dzw);

    % Build name of 2D x-y file to read
    yfile = ['run000003_xy_diags_',num2str(time,'%010i'),'.dat']

    % Retrieve the required field
    [ctop,model_time,x,y,levels] = retrieve_field(yfile,'ctop');
    nx = numel(x);
    ny = numel(y);

    % Define cloud to be where cloud top > 100m
    cldcov(nt) = sum(ctop > 100,'all')/(nx*ny);
 
end

% Convert to minutes
mtime = mtime/60;

subplot(3,1,1)
plot(mtime,cldcov,'k','linewidth',1.5)
xlim([0,mtime(end)])
xticks(0:60:mtime(end))
%xlabel('Time (min)')
ylabel('(a) Total cloud cover')
set(gca,'fontsize',12)

subplot(3,1,2)
plot(mtime,collwp,'k','linewidth',1.5)
xlim([0,mtime(end)])
xticks(0:60:mtime(end))
%xlabel('Time (min)')
ylabel('(b) LWP (kg m^{-2})')
set(gca,'fontsize',12)

subplot(3,1,3)
plot(mtime,coltke,'k','linewidth',1.5)
xlim([0,mtime(end)])
xticks(0:60:mtime(end))
xlabel('Time (min)')
ylabel('(c) TKE (kg m^{-1}s^{-2})')
set(gca,'fontsize',12)

